summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/configuration-common.nix
diff options
context:
space:
mode:
authorsternenseemann <sternenseemann@systemli.org>2023-07-24 22:29:06 +0200
committersternenseemann <sternenseemann@systemli.org>2023-07-25 02:21:57 +0200
commit500b36d057ceaa7ad3e2e282958a44ed607b021f (patch)
treef2f5efe98541b3e12ea71a1c79a969825d17fbdb /pkgs/development/haskell-modules/configuration-common.nix
parent5c13e0de2686e8d9bc67586385b85869243fea19 (diff)
downloadnixpkgs-500b36d057ceaa7ad3e2e282958a44ed607b021f.tar
nixpkgs-500b36d057ceaa7ad3e2e282958a44ed607b021f.tar.gz
nixpkgs-500b36d057ceaa7ad3e2e282958a44ed607b021f.tar.bz2
nixpkgs-500b36d057ceaa7ad3e2e282958a44ed607b021f.tar.lz
nixpkgs-500b36d057ceaa7ad3e2e282958a44ed607b021f.tar.xz
nixpkgs-500b36d057ceaa7ad3e2e282958a44ed607b021f.tar.zst
nixpkgs-500b36d057ceaa7ad3e2e282958a44ed607b021f.zip
all-cabal-hashes: 2023-07-19T20:56:38Z -> 2023-07-24T19:28:29Z
The main motivation for this is that the latest versions of hspec-core
and hspec-expectations got out of sync due to an unlucky timing on the
hackage snapshot update. As a consequence, we weren't able to build
cabal-install in some package sets. Additionally, this brings a version
of futhark that can be built with the lsp version we ship.

This commit has been generated by maintainers/scripts/haskell/update-hackage.sh
and maintainers/scripts/haskell/regenerate-hackage-packages.nix.

Additional changes:

* Adapt to new xhtml version (still doesn't match the version normally
  shipped by the respective GHC as a core library).

* Adapt to new versions of hspec* and pandoc
Diffstat (limited to 'pkgs/development/haskell-modules/configuration-common.nix')
-rw-r--r--pkgs/development/haskell-modules/configuration-common.nix28
1 files changed, 14 insertions, 14 deletions
diff --git a/pkgs/development/haskell-modules/configuration-common.nix b/pkgs/development/haskell-modules/configuration-common.nix
index 3fe6c6aadc6..1e433a13e28 100644
--- a/pkgs/development/haskell-modules/configuration-common.nix
+++ b/pkgs/development/haskell-modules/configuration-common.nix
@@ -57,15 +57,15 @@ self: super: {
           # not solvable short of recompiling GHC. Instead of adding
           # allowInconsistentDependencies for all reverse dependencies of hspec-core,
           # just upgrade to an hspec version without the offending dependency.
-          hspec-core = cself.hspec-core_2_11_3;
-          hspec-discover = cself.hspec-discover_2_11_3;
-          hspec = cself.hspec_2_11_3;
+          hspec-core = cself.hspec-core_2_11_4;
+          hspec-discover = cself.hspec-discover_2_11_4;
+          hspec = cself.hspec_2_11_4;
 
           # hspec-discover and hspec-core depend on hspec-meta for testing which
           # we need to avoid since it depends on ghc as well. Since hspec*_2_11*
           # are overridden to take the versioned attributes as inputs, we need
           # to make sure to override the versioned attribute with this fix.
-          hspec-discover_2_11_3 = dontCheck csuper.hspec-discover_2_11_3;
+          hspec-discover_2_11_4 = dontCheck csuper.hspec-discover_2_11_4;
 
           # Prevent dependency on doctest which causes an inconsistent dependency
           # due to depending on ghc which depends on directory etc.
@@ -297,7 +297,7 @@ self: super: {
     })
     # Overriding the version pandoc dependency uses as the latest release has version bounds
     # defined as >= 3.1  && < 3.2, can be removed once pandoc gets bumped by Stackage.
-  ] (super.patat.override { pandoc = self.pandoc_3_1_5; });
+  ] (super.patat.override { pandoc = self.pandoc_3_1_6; });
 
   # The latest release on hackage has an upper bound on containers which
   # breaks the build, though it works with the version of containers present
@@ -1732,14 +1732,14 @@ self: super: {
   servant-openapi3 = dontCheck super.servant-openapi3;
 
   # Give latest hspec correct dependency versions without overrideScope
-  hspec_2_11_3 = doDistribute (super.hspec_2_11_3.override {
-    hspec-discover = self.hspec-discover_2_11_3;
-    hspec-core = self.hspec-core_2_11_3;
+  hspec_2_11_4 = doDistribute (super.hspec_2_11_4.override {
+    hspec-discover = self.hspec-discover_2_11_4;
+    hspec-core = self.hspec-core_2_11_4;
   });
-  hspec-discover_2_11_3 = doDistribute super.hspec-discover_2_11_3;
-  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_3
+  hspec-discover_2_11_4 = doDistribute super.hspec-discover_2_11_4;
+  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_4
   # is overlayed to hspec-core.
-  hspec-core_2_11_3 = doDistribute (dontCheck (super.hspec-core_2_11_3.override {
+  hspec-core_2_11_4 = doDistribute (dontCheck (super.hspec-core_2_11_4.override {
     hspec-expectations = self.hspec-expectations_0_8_4;
   }));
 
@@ -1907,7 +1907,7 @@ self: super: {
   inherit (let
     pandoc-cli-overlay = self: super: {
       # pandoc-cli requires pandoc >= 3.1
-      pandoc = self.pandoc_3_1_5;
+      pandoc = self.pandoc_3_1_6;
 
       # pandoc depends on crypton-connection, which requires tls >= 1.7
       tls = self.tls_1_7_0;
@@ -1918,11 +1918,11 @@ self: super: {
     };
   in {
     pandoc-cli = super.pandoc-cli.overrideScope pandoc-cli-overlay;
-    pandoc_3_1_5 = doDistribute (super.pandoc_3_1_5.overrideScope pandoc-cli-overlay);
+    pandoc_3_1_6 = doDistribute (super.pandoc_3_1_6.overrideScope pandoc-cli-overlay);
     pandoc-lua-engine = super.pandoc-lua-engine.overrideScope pandoc-cli-overlay;
   })
     pandoc-cli
-    pandoc_3_1_5
+    pandoc_3_1_6
     pandoc-lua-engine
     ;